@@ -254,10 +254,12 @@ def edit(img, *filters, scaling = 4, demo = False):
     return img
 
 def fits(img, threshold = 64):
-    is_np = img.__class__ == numpy.ndarray
-    is_pil = img.__class__ == PIL.Image.Image
+    print("hello")
     if img.__class__ == numpy.ndarray:
         #should change X and Y?
+        print(img.shape)
+        print(img)
+        print(img[0])
         for x in range(img.shape[0]):
             if img[x][0] > threshold or img[x][img.shape[1] - 1] > threshold:
                 return False
